@@ -12,12 +12,13 @@ class ResetHead(HeadMotion):
     The head will continuously move over multiple `communicate()` calls until it is at its neutral rotation.
     """
 
-    def __init__(self, duration: float):
+    def __init__(self, duration: float, scale_duration: bool):
         """
         :param duration: The duration of the motion in seconds.
+        :param scale_duration: If True, `duration` will be multiplied by `framerate / 60)`, ensuring smoother motions at faster-than-life simulation speeds.
         """
 
-        super().__init__(duration=duration)
+        super().__init__(duration=duration, scale_duration=scale_duration)
 
     def get_initialization_commands(self, resp: List[bytes], static: ReplicantStatic, dynamic: ReplicantDynamic,
                                     image_frequency: ImageFrequency) -> List[dict]:
